pub fn active_tensor_executor(cx: &Cx) -> Option<Arc<dyn TensorExecutor>>Expand description
Returns the tensor executor currently bound in the active environment.
pub fn active_tensor_executor(cx: &Cx) -> Option<Arc<dyn TensorExecutor>>Returns the tensor executor currently bound in the active environment.