pub fn execute_tensor_binary_op(
cx: &mut Cx,
operator: Symbol,
left: &Tensor,
right: &Tensor,
) -> Result<Tensor>Expand description
Runs a binary tensor operation through the active executor, or CPU when no executor is bound in the environment.