BoxedTensorStorage

Struct BoxedTensorStorage 

pub struct BoxedTensorStorage { /* private fields */ }
Boxed host storage for scalar runtime values.

This is the default storage used by tensor constructors. Its cells are reference counted so tensor clones and repeated observations preserve value identity without copying the cell vector.