pub struct TensorSite { /* private fields */ }Expand description
Eval-fabric wrapper that binds one tensor executor for a realization.
Implementations
Sourceimpl TensorSite
impl TensorSite
Sourcepub fn new(
symbol: Symbol,
executor: Arc<dyn TensorExecutor>,
capabilities: Vec<CapabilityName>,
) -> Self
pub fn new( symbol: Symbol, executor: Arc<dyn TensorExecutor>, capabilities: Vec<CapabilityName>, ) -> Self
Builds a tensor site around an executor and required capability set.
Sourcepub fn card(&self) -> TensorExecutorCard
pub fn card(&self) -> TensorExecutorCard
Returns the executor card exposed by this site.
Sourcepub fn capabilities(&self) -> &[CapabilityName]
pub fn capabilities(&self) -> &[CapabilityName]
Returns the capabilities this site requires for realization.