execute_tensor_binary_op

Function execute_tensor_binary_op 

pub fn execute_tensor_binary_op(
    cx: &mut Cx,
    operator: Symbol,
    left: &Tensor,
    right: &Tensor,
) -> Result<Tensor>
Runs a binary tensor operation through the active executor, or CPU when no executor is bound in the environment.