pub fn execute_tensor_unary_op( cx: &mut Cx, operator: Symbol, tensor: &Tensor, ) -> Result<Tensor>
Runs a unary tensor operation through the active executor, or CPU when no executor is bound in the environment.